@@ -11,7 +11,7 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 
 	struct cfgsetting cset[] =
 		{/* cfg string, char var name, int var name, char len, fill status */
-		 {"Interface", cfg.iface, 0, 32, 0},
+		 {"Interface", cfg.iface, 0, MAXIFPARAMLEN, 0},
 		 {"DatabaseDir", cfg.dbdir, 0, 512, 0},
 		 {"Locale", cfg.locale, 0, 32, 0},
 		 {"MonthRotate", 0, &cfg.monthrotate, 0, 0},
@@ -45,6 +45,8 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 		 {"ListYears", 0, &cfg.listyears, 0, 0},
 		 {"ListTop", 0, &cfg.listtop, 0, 0},
 		 {"InterfaceMatchMethod", 0, &cfg.ifacematchmethod, 0, 0},
+		 {"EstimateVisible", 0, &cfg.estimatevisible, 0, 0},
+		 {"EstimateText", cfg.estimatetext, 0, 10, 0},
 		 {"5MinuteHours", 0, &cfg.fiveminutehours, 0, 0},
 		 {"HourlyDays", 0, &cfg.hourlydays, 0, 0},
 		 {"DailyDays", 0, &cfg.dailydays, 0, 0},
@@ -99,9 +101,6 @@ int loadcfg(const char *cfgfile, const ConfigType type)
 		 {"Experimental", 0, &cfg.experimental, 0, 0},
 		 {0, 0, 0, 0, 0}};
 
-	/* load default config */
-	defaultcfg();
-
 	i = opencfgfile(cfgfile, &fd);
 	if (i != 2)
 		return i;
@@ -233,6 +232,7 @@ void validatecfg(const ConfigType type)
 	validateint("ListYears", &cfg.listyears, LISTYEARS, 0, 0);
 	validateint("ListTop", &cfg.listtop, LISTTOP, 0, 0);
 	validateint("InterfaceMatchMethod", &cfg.ifacematchmethod, IFACEMATCHMETHOD, 0, 3);
+	validatebool("EstimateVisible", &cfg.estimatevisible, ESTIMATEVISIBLE);
 	validateint("5MinuteHours", &cfg.fiveminutehours, FIVEMINUTEHOURS, -1, -1);
 	validateint("HourlyDays", &cfg.hourlydays, HOURLYDAYS, -1, -1);
 	validateint("DailyDays", &cfg.dailydays, DAILYDAYS, -1, -1);
@@ -364,6 +364,8 @@ void defaultcfg(void)
 	cfg.trafficlessentries = TRAFFICLESSENTRIES;
 	cfg.utflocale = UTFLOCALE;
 	cfg.ifacematchmethod = IFACEMATCHMETHOD;
+	cfg.estimatevisible = ESTIMATEVISIBLE;
+	strncpy_nt(cfg.estimatetext, ESTIMATETEXT, 10);
 
 	cfg.listfivemins = LISTFIVEMINS;
 	cfg.listhours = LISTHOURS;
@@ -382,7 +384,7 @@ void defaultcfg(void)
 
 	strncpy_nt(cfg.dbdir, DATABASEDIR, 512);
 	strncpy_nt(cfg.dbtzmodifier, DATABASELOCALTIMEMODIFIER, 14);
-	strncpy_nt(cfg.iface, DEFIFACE, 32);
+	strncpy_nt(cfg.iface, DEFIFACE, MAXIFPARAMLEN);
 	strncpy_nt(cfg.locale, LOCALE, 32);
 	strncpy_nt(cfg.dformat, DFORMAT, 64);
 	strncpy_nt(cfg.mformat, MFORMAT, 64);
