@@ -159,6 +159,10 @@ and most can be changed later from the config file.
 /* 2 = 1 + case insensitive exact alias, 3 = 2 + case insensitive beginning of alias */
 #define IFACEMATCHMETHOD 3
 
+/* estimate line visibility and text */
+#define ESTIMATEVISIBLE 1
+#define ESTIMATETEXT "estimated"
+
 /* how much the boot time can variate between updates (seconds) */
 #define BVAR 15
 
@@ -297,6 +301,10 @@ and most can be changed later from the config file.
 #define CTX "606060"
 #define CTXD "-"
 
+/* interface name length limit */
+#define MAXIFLEN 32
+#define MAXIFPARAMLEN 256
+
 /* number of retries after non-fatal database errors, */
 /* will result in given number + 1 tries in total before exit, */
 /* a full disk (as reported by sqlite) will no cause retries or exit */
@@ -305,16 +313,16 @@ and most can be changed later from the config file.
 /* internal config structure */
 typedef struct {
 	char dformat[64], mformat[64], tformat[64], hformat[64];
-	char iface[32];
+	char iface[MAXIFPARAMLEN];
 	char locale[32];
 	char dbdir[512], dbtzmodifier[14];
-	char rxchar[2], txchar[2], rxhourchar[2], txhourchar[2];
+	char rxchar[2], txchar[2], rxhourchar[2], txhourchar[2], estimatetext[10];
 	char cbg[8], cedge[8], cheader[8], cheadertitle[8], cheaderdate[8], ctext[8];
 	char cline[8], clinel[8], cvnstat[8], crx[8], crxd[8], ctx[8], ctxd[8];
 	int32_t unitmode, rateunitmode, rateunit, bvar, qmode, ifacematchmethod, sampletime, hourlyrate, summaryrate;
 	int32_t monthrotate, monthrotateyears, maxbw, spacecheck, trafficlessentries, transbg, ostyle;
 	int32_t defaultdecimals, hourlydecimals, hourlystyle, is64bit, waldb, dbsynchronous, useutc, imagescale;
-	int32_t largefonts, linespaceadjust, estimatebarvisible, estimatestyle, barshowsrate, fivegresultcount;
+	int32_t largefonts, linespaceadjust, estimatebarvisible, estimatestyle, estimatevisible, barshowsrate, fivegresultcount;
 	int32_t fivegheight, summarygraph, hourlygmode, alwaysadd;
 	char cfgfile[512], logfile[512], pidfile[512];
 	char daemonuser[33], daemongroup[33];
@@ -327,7 +335,7 @@ typedef struct {
 
 /* internal interface information structure */
 typedef struct {
-	char name[32];
+	char name[MAXIFLEN];
 	short filled;
 	short is64bit;
 	uint64_t rx;
@@ -338,7 +346,7 @@ typedef struct {
 } IFINFO;
 
 typedef struct ibwnode {
-	char interface[32];
+	char interface[MAXIFLEN];
 	uint32_t limit;
 	uint32_t fallback;
 	short retries;
