@@ -266,6 +266,9 @@ void initdstate(DSTATE *s)
 	s->dbretrycount = 0;
 	s->dcache = NULL;
 	s->prevwaldbcheckpoint = time(NULL);
+
+	/* load default config */
+	defaultcfg();
 }
 
 void preparedatabase(DSTATE *s)
@@ -518,7 +521,7 @@ int processifinfo(DSTATE *s, datacache **dc)
 		/* skip update if previous update is less than a day in the future */
 		/* otherwise exit with error message since the clock is probably messed */
 		if ((*dc)->updated > (ifinfo.timestamp + 86400)) {
-			snprintf(errorstring, 1024, "Interface \"%s\" has previous update date too much in the future, exiting. (%u / %u)", (*dc)->interface, (unsigned int)(*dc)->updated, (unsigned int)ifinfo.timestamp);
+			snprintf(errorstring, 1024, "Interface \"%s\" has previous update date too much in the future, exiting. (%" PRIu64 " / %" PRIu64 ")", (*dc)->interface, (uint64_t)(*dc)->updated, (uint64_t)ifinfo.timestamp);
 			printe(PT_Error);
 			errorexitdaemon(s, 1);
 		}
@@ -791,6 +794,7 @@ void handleintsignals(DSTATE *s)
 			s->dbifcount = 0;
 			ibwflush();
 			db_close();
+			defaultcfg();
 			loadcfg(s->cfgfile, CT_Daemon);
 			ibwloadcfg(s->cfgfile);
 			if (!db_open_rw(1)) {
