@@ -103,7 +103,11 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 		strftime(datebuff, DATEBUFFLEN, cfg.tformat, d);
 		printf(" since %s\n\n", datebuff);
 
-		indent(10);
+		if (cfg.ostyle == 1) {
+			indent(3);
+		} else {
+			indent(10);
+		}
 		printf("rx:  %s", getvalue(interface->rxtotal, 1, RT_Normal));
 		indent(3);
 		printf("   tx:  %s", getvalue(interface->txtotal, 1, RT_Normal));
@@ -143,22 +147,19 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 		}
 		printf("%s%s", fieldseparator, getvalue(datalist_i->tx, 11, RT_Normal));
 		printf("%s%s", fieldseparator, getvalue(datalist_i->rx + datalist_i->tx, 11, RT_Normal));
-		if (cfg.ostyle >= 2) {
-			if (datalist_i->next == NULL && issametimeslot(LT_Month, datalist_i->timestamp, interface->updated)) {
-				if (datalist_i->rx == 0 || datalist_i->tx == 0 || (interface->updated - datalist_i->timestamp) == 0) {
-					e_rx = e_tx = 0;
-				} else {
-					e_rx = (uint64_t)((double)datalist_i->rx / (double)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
-					e_tx = (uint64_t)((double)datalist_i->tx / (double)(mosecs(datalist_i->timestamp, interface->updated))) * (uint64_t)(dmonth(d->tm_mon) * 86400);
-				}
-				if (shortmode && cfg.ostyle != 0) {
-					printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
-				} else if (!shortmode) {
-					printf("%s%s", fieldseparator, gettrafficrate(datalist_i->rx + datalist_i->tx, mosecs(datalist_i->timestamp, interface->updated), 14));
-				}
-			} else if (!shortmode) {
-				printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, dmonth(d->tm_mon) * 86400, 14));
+		if (datalist_i->next == NULL && issametimeslot(LT_Month, datalist_i->timestamp, interface->updated)) {
+			if (datalist_i->rx == 0 || datalist_i->tx == 0 || (interface->updated - datalist_i->timestamp) == 0) {
+				e_rx = e_tx = 0;
+			} else if (cfg.estimatevisible) {
+				getestimates(&e_rx, &e_tx, LT_Month, interface->updated, interface->created, &datalist);
 			}
+			if (shortmode && cfg.ostyle != 0 && cfg.estimatevisible) {
+				printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
+			} else if (!shortmode && cfg.ostyle >= 2) {
+				printf("%s%s", fieldseparator, gettrafficrate(datalist_i->rx + datalist_i->tx, (time_t)getperiodseconds(LT_Month, datalist_i->timestamp, interface->updated, interface->created, 1), 14));
+			}
+		} else if (!shortmode && cfg.ostyle >= 2) {
+			printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, dmonth(d->tm_mon) * 86400, 14));
 		}
 		printf("\n");
 		datalist_i = datalist_i->next;
@@ -176,15 +177,18 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 		} else {
 			printf("------------------------+-------------+------------\n");
 		}
-		indent(5);
-		printf("estimated   %s", getvalue(e_rx, 11, RT_Estimate));
-		printf(" | %s", getvalue(e_tx, 11, RT_Estimate));
-		printf(" | %s", getvalue(e_rx + e_tx, 11, RT_Estimate));
-		if (cfg.ostyle >= 2) {
-			printf(" |\n\n");
-		} else {
-			printf("\n\n");
+		if (cfg.estimatevisible) {
+			indent(5);
+			printf("%9s   %s", cfg.estimatetext, getvalue(e_rx, 11, RT_Estimate));
+			printf(" | %s", getvalue(e_tx, 11, RT_Estimate));
+			printf(" | %s", getvalue(e_rx + e_tx, 11, RT_Estimate));
+			if (cfg.ostyle >= 2) {
+				printf(" |\n");
+			} else {
+				printf("\n");
+			}
 		}
+		printf("\n");
 	}
 
 	dbdatalistfree(&datalist);
@@ -235,23 +239,21 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 		}
 		printf("%s%s", fieldseparator, getvalue(datalist_i->tx, 11, RT_Normal));
 		printf("%s%s", fieldseparator, getvalue(datalist_i->rx + datalist_i->tx, 11, RT_Normal));
-		if (cfg.ostyle >= 2) {
-			if (datalist_i->next == NULL && issametimeslot(LT_Day, datalist_i->timestamp, interface->updated)) {
-				d = localtime(&interface->updated);
-				if (datalist_i->rx == 0 || datalist_i->tx == 0 || (d->tm_hour * 60 + d->tm_min) == 0) {
-					e_rx = e_tx = 0;
-				} else {
+		if (datalist_i->next == NULL && issametimeslot(LT_Day, datalist_i->timestamp, interface->updated)) {
+			d = localtime(&interface->updated);
+			if (datalist_i->rx == 0 || datalist_i->tx == 0 || (d->tm_hour * 60 + d->tm_min) == 0) {
+				e_rx = e_tx = 0;
+			} else if (cfg.estimatevisible) {
 					e_rx = (uint64_t)((double)datalist_i->rx / (double)(d->tm_hour * 60 + d->tm_min)) * 1440;
 					e_tx = (uint64_t)((double)datalist_i->tx / (double)(d->tm_hour * 60 + d->tm_min)) * 1440;
-				}
-				if (shortmode && cfg.ostyle != 0) {
-					printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
-				} else if (!shortmode) {
-					printf("%s%s", fieldseparator, gettrafficrate(datalist_i->rx + datalist_i->tx, d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600), 14));
-				}
-			} else if (!shortmode) {
-				printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, 86400, 14));
 			}
+			if (shortmode && cfg.ostyle != 0 && cfg.estimatevisible) {
+				printf("%s%s", fieldseparator, getvalue(e_rx + e_tx, 11, RT_Estimate));
+			} else if (!shortmode && cfg.ostyle >= 2) {
+				printf("%s%s", fieldseparator, gettrafficrate(datalist_i->rx + datalist_i->tx, (time_t)getperiodseconds(LT_Day, datalist_i->timestamp, interface->updated, interface->created, 1), 14));
+			}
+		} else if (!shortmode && cfg.ostyle >= 2) {
+			printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, 86400, 14));
 		}
 		printf("\n");
 		datalist_i = datalist_i->next;
@@ -268,14 +270,16 @@ void showsummary(const interfaceinfo *interface, const int shortmode)
 		} else {
 			printf("------------------------+-------------+------------\n");
 		}
-		indent(5);
-		printf("estimated   %s", getvalue(e_rx, 11, RT_Estimate));
-		printf(" | %s", getvalue(e_tx, 11, RT_Estimate));
-		printf(" | %s", getvalue(e_rx + e_tx, 11, RT_Estimate));
-		if (cfg.ostyle >= 2) {
-			printf(" |\n");
-		} else {
-			printf("\n");
+		if (cfg.estimatevisible) {
+			indent(5);
+			printf("%9s   %s", cfg.estimatetext, getvalue(e_rx, 11, RT_Estimate));
+			printf(" | %s", getvalue(e_tx, 11, RT_Estimate));
+			printf(" | %s", getvalue(e_rx + e_tx, 11, RT_Estimate));
+			if (cfg.ostyle >= 2) {
+				printf(" |\n");
+			} else {
+				printf("\n");
+			}
 		}
 	} else {
 		printf("\n");
@@ -364,9 +368,9 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 
 	datalist_i = datalist;
 
-	if (strlen(dataend) == 0 && datainfo.count > 0 && (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year)) {
+	if (strlen(dataend) == 0 && datainfo.count > 0 && (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year) && cfg.estimatevisible) {
 		estimatevisible = 1;
-		getestimates(&e_rx, &e_tx, listtype, interface->updated, &datalist);
+		getestimates(&e_rx, &e_tx, listtype, interface->updated, interface->created, &datalist);
 		if (cfg.estimatebarvisible && e_rx + e_tx > datainfo.max) {
 			datainfo.max = e_rx + e_tx;
 		}
@@ -480,9 +484,9 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 		printf(" | %s", getvalue(datalist_i->rx + datalist_i->tx, 11, RT_Normal));
 		if (cfg.ostyle == 3) {
 			if (datalist_i->next == NULL && issametimeslot(listtype, datalist_i->timestamp, interface->updated)) {
-				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, 1);
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, interface->created, 1);
 			} else {
-				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, 0);
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, interface->updated, interface->created, 0);
 			}
 			printf(" | %s", gettrafficrate(datalist_i->rx + datalist_i->tx, (time_t)e_secs, 14));
 		} else if (cfg.ostyle != 0) {
@@ -531,7 +535,12 @@ void showlist(const interfaceinfo *interface, const char *listname, const char *
 			printf("    ");
 		}
 		if (strlen(dataend) == 0) {
-			printf(" estimated   %s", getvalue(e_rx, 11, RT_Estimate));
+			if (strlen(datebuff) <= 9) {
+				printf(" %9s ", cfg.estimatetext);
+			} else {
+				printf("  %9s", cfg.estimatetext);
+			}
+			printf("  %s", getvalue(e_rx, 11, RT_Estimate));
 			printf(" | %s", getvalue(e_tx, 11, RT_Estimate));
 			printf(" | %s", getvalue(e_rx + e_tx, 11, RT_Estimate));
 		} else {
@@ -590,14 +599,12 @@ void showoneline(const interfaceinfo *interface)
 		strftime(daytemp, DATEBUFFLEN, cfg.dformat, d);
 		printf("%s;", daytemp);
 
-		d = localtime(&interface->updated);
-
 		/* daily */
 		if (cfg.ostyle == 4) {
 			printf("%" PRIu64 ";", datalist->rx);
 			printf("%" PRIu64 ";", datalist->tx);
 			printf("%" PRIu64 ";", datalist->rx + datalist->tx);
-			div = (uint64_t)(d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600));
+			div = getperiodseconds(LT_Day, datalist->timestamp, interface->updated, interface->created, 1);
 			if (!div) {
 				div = 1;
 			}
@@ -606,7 +613,7 @@ void showoneline(const interfaceinfo *interface)
 			printf("%s;", getvalue(datalist->rx, 1, RT_Normal));
 			printf("%s;", getvalue(datalist->tx, 1, RT_Normal));
 			printf("%s;", getvalue(datalist->rx + datalist->tx, 1, RT_Normal));
-			printf("%s;", gettrafficrate(datalist->rx + datalist->tx, (time_t)(d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600)), 1));
+			printf("%s;", gettrafficrate(datalist->rx + datalist->tx, (time_t)getperiodseconds(LT_Day, datalist->timestamp, interface->updated, interface->created, 1), 1));
 		}
 	} else {
 		printf(";;;;;");
@@ -628,7 +635,7 @@ void showoneline(const interfaceinfo *interface)
 			printf("%" PRIu64 ";", datalist->rx);
 			printf("%" PRIu64 ";", datalist->tx);
 			printf("%" PRIu64 ";", datalist->rx + datalist->tx);
-			div = (uint64_t)(mosecs(datalist->timestamp, interface->updated));
+			div = getperiodseconds(LT_Month, datalist->timestamp, interface->updated, interface->created, 1);
 			if (!div) {
 				div = 1;
 			}
@@ -637,7 +644,7 @@ void showoneline(const interfaceinfo *interface)
 			printf("%s;", getvalue(datalist->rx, 1, RT_Normal));
 			printf("%s;", getvalue(datalist->tx, 1, RT_Normal));
 			printf("%s;", getvalue(datalist->rx + datalist->tx, 1, RT_Normal));
-			printf("%s;", gettrafficrate(datalist->rx + datalist->tx, mosecs(datalist->timestamp, interface->updated), 1));
+			printf("%s;", gettrafficrate(datalist->rx + datalist->tx, (time_t)getperiodseconds(LT_Month, datalist->timestamp, interface->updated, interface->created, 1), 1));
 		}
 	} else {
 		printf(";;;;;");
@@ -881,13 +888,6 @@ int showbar(const uint64_t rx, const uint64_t tx, const uint64_t max, const int
 	return width;
 }
 
-void indent(int i)
-{
-	if ((cfg.ostyle > 0) && (i > 0)) {
-		printf("%*s", i, " ");
-	}
-}
-
 int showalert(const char *interface, const AlertOutput output, const AlertExit exit, const AlertType type, const AlertCondition condition, const uint64_t limit)
 {
 	interfaceinfo ifaceinfo;
@@ -944,40 +944,46 @@ int showalert(const char *interface, const AlertOutput output, const AlertExit e
 
 	switch (condition) {
 		case AC_None:
-			break;
+			return 0;
 		case AC_RX:
 			bytes = datalist->rx;
 			snprintf(conditionname, 16, "rx");
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
-			e_bytes = e_rx;
+			if (cfg.estimatevisible) {
+				getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
+				e_bytes = e_rx;
+			}
 			break;
 		case AC_TX:
 			bytes = datalist->tx;
 			snprintf(conditionname, 16, "tx");
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
-			e_bytes = e_tx;
+			if (cfg.estimatevisible) {
+				getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
+				e_bytes = e_tx;
+			}
 			break;
 		case AC_Total:
 			bytes = datalist->rx + datalist->tx;
 			snprintf(conditionname, 16, "total");
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
-			e_bytes = e_rx + e_tx;
+			if (cfg.estimatevisible) {
+				getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
+				e_bytes = e_rx + e_tx;
+			}
 			break;
 		case AC_RX_Estimate:
 			ongoing = 0;
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
+			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
 			bytes = e_rx;
 			snprintf(conditionname, 16, "rx estimate");
 			break;
 		case AC_TX_Estimate:
 			ongoing = 0;
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
+			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
 			bytes = e_tx;
 			snprintf(conditionname, 16, "tx estimate");
 			break;
 		case AC_Total_Estimate:
 			ongoing = 0;
-			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, &datalist);
+			getestimates(&e_rx, &e_tx, listtype, ifaceinfo.updated, ifaceinfo.created, &datalist);
 			bytes = e_rx + e_tx;
 			snprintf(conditionname, 16, "total estimate");
 			break;
@@ -1050,7 +1056,7 @@ int showalert(const char *interface, const AlertOutput output, const AlertExit e
 			for (i = 0; i < l; i++) {
 				printf("=");
 			}
-			if (ongoing) {
+			if (ongoing && cfg.estimatevisible) {
 				if (!estimateexceeded) {
 					l = (int)lrint((double)(e_bytes) / (double)limit * ALERTUSAGELEN);
 					for (; i < l; i++) {
@@ -1079,9 +1085,9 @@ int showalert(const char *interface, const AlertOutput output, const AlertExit e
 			printf("   percentage   |   avg. rate\n");
 			printf("     ----------+------------------+----------------+--------------\n");
 			printf("          used | %16s |", getvalue(bytes, 16, RT_Normal));
-			periodseconds = getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, ongoing);
+			periodseconds = getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, ifaceinfo.created, ongoing);
 			if (ongoing && periodseconds == 0) {
-				periodseconds = getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, 0);
+				periodseconds = getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, ifaceinfo.created, 0);
 			}
 			if (percentage <= 100000.0) {
 				printf(" %13.1f%% | %13s\n", percentage, gettrafficrate(bytes, (time_t)periodseconds, 13));
@@ -1089,7 +1095,7 @@ int showalert(const char *interface, const AlertOutput output, const AlertExit e
 				printf(" %14s | %13s\n", ">100000%", gettrafficrate(bytes, (time_t)periodseconds, 13));
 			}
 			printf("         limit | %16s |", getvalue(limit, 16, RT_Normal));
-			printf("                | %13s\n", gettrafficrate(limit, (time_t)getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, 0), 13));
+			printf("                | %13s\n", gettrafficrate(limit, (time_t)getperiodseconds(listtype, datalist->timestamp, ifaceinfo.updated, ifaceinfo.created, 0), 13));
 
 			if (limitexceeded) {
 				printf("        excess | %16s |                |\n", getvalue(bytes - limit, 16, RT_Normal));
@@ -1098,8 +1104,8 @@ int showalert(const char *interface, const AlertOutput output, const AlertExit e
 				printf("     remaining | %16s | %13.1f%% |\n", getvalue(limit - bytes, 16, RT_Normal), 100.0 - percentage);
 				printf("     ----------+------------------+----------------+--------------\n");
 			}
-			if (ongoing && e_bytes > 0) {
-				printf("     estimated | %16s |", getvalue(e_bytes, 16, RT_Normal));
+			if (ongoing && cfg.estimatevisible && e_bytes > 0) {
+				printf("     %9s | %16s |", cfg.estimatetext, getvalue(e_bytes, 16, RT_Normal));
 				percentage = (double)(e_bytes) / (double)limit * 100.0;
 				if (percentage <= 100000.0) {
 					printf(" %13.1f%%", percentage);
