@@ -367,12 +367,12 @@ void drawlist(IMAGECONTENT *ic, const char *listname)
 	datalist_i = datalist;
 
 	if (strlen(ic->dataend) == 0 && datainfo.count > 0 && listtype != LT_Top) {
-		getestimates(&e_rx, &e_tx, listtype, ic->interface.updated, &datalist);
+		getestimates(&e_rx, &e_tx, listtype, ic->interface.updated, ic->interface.created, &datalist);
 		if ((cfg.estimatestyle > 0 || cfg.barshowsrate > 0) && e_rx + e_tx > datainfo.max) {
 			datainfo.max = e_rx + e_tx;
 		}
 		estimateavailable = 1;
-		if (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year) {
+		if (cfg.estimatevisible && (listtype == LT_Day || listtype == LT_Month || listtype == LT_Year)) {
 			estimatevisible = 1;
 		}
 	}
@@ -406,8 +406,8 @@ void drawlist(IMAGECONTENT *ic, const char *listname)
 	width = 83 * ic->font->w + 2 + (ic->large * 2);
 	height = 62 + 3 * ic->lineheight;
 
-	// less space needed when no estimate or sum is shown (Top, 5min and Hour never have estimate)
-	if ((!estimatevisible && datainfo.count < 2) || (listtype == LT_Top || listtype == LT_Hour || listtype == LT_5min)) {
+	// less space needed when no estimate or sum is shown
+	if (!estimatevisible && !(strlen(ic->dataend) > 0 && datainfo.count > 1 && listtype != LT_Top)) {
 		height = 62 + 2 * ic->lineheight;
 	}
 
@@ -532,9 +532,9 @@ void drawlist(IMAGECONTENT *ic, const char *listname)
 		if (cfg.ostyle > 2) {
 			strcat(buffer, "  ");
 			if (datalist_i->next == NULL && issametimeslot(listtype, datalist_i->timestamp, ic->interface.updated)) {
-				e_secs = getperiodseconds(listtype, datalist_i->timestamp, ic->interface.updated, 1);
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, ic->interface.updated, ic->interface.created, 1);
 			} else {
-				e_secs = getperiodseconds(listtype, datalist_i->timestamp, ic->interface.updated, 0);
+				e_secs = getperiodseconds(listtype, datalist_i->timestamp, ic->interface.updated, ic->interface.created, 0);
 			}
 			strncat(buffer, gettrafficrate(datalist_i->rx + datalist_i->tx, (time_t)e_secs, 14), 32);
 		}
@@ -584,7 +584,11 @@ void drawlist(IMAGECONTENT *ic, const char *listname)
 
 	/* estimate visible */
 	if (estimatevisible) {
-		snprintf(buffer, 32, " estimated   ");
+		if (strlen(datebuff) <= 9) {
+			snprintf(buffer, 32, " %9s   ", cfg.estimatetext);
+		} else {
+			snprintf(buffer, 32, "  %9s  ", cfg.estimatetext);
+		}
 		strncat(buffer, getvalue(e_rx, 10, RT_Estimate), 32);
 		strcat(buffer, "   ");
 		strncat(buffer, getvalue(e_tx, 10, RT_Estimate), 32);
@@ -813,9 +817,9 @@ void drawsummary_digest(IMAGECONTENT *ic, const int x, const int y, const char *
 	if (cfg.summaryrate) {
 		d = localtime(&ic->interface.updated);
 		if (mode[0] == 'd') {
-			snprintf(buffer, 16, "%15s", gettrafficrate(data_current->rx + data_current->tx, d->tm_sec + (d->tm_min * 60) + (d->tm_hour * 3600), 15));
+			snprintf(buffer, 16, "%15s", gettrafficrate(data_current->rx + data_current->tx, (time_t)getperiodseconds(LT_Day, data_current->timestamp, ic->interface.updated, ic->interface.created, 1), 15));
 		} else if (mode[0] == 'm') {
-			snprintf(buffer, 16, "%15s", gettrafficrate(data_current->rx + data_current->tx, mosecs(data_current->timestamp, ic->interface.updated), 15));
+			snprintf(buffer, 16, "%15s", gettrafficrate(data_current->rx + data_current->tx, (time_t)getperiodseconds(LT_Month, data_current->timestamp, ic->interface.updated, ic->interface.created, 1), 15));
 		}
 		gdImageString(ic->im, ic->font, textx - 74, texty + 4 * ic->lineheight + 10, (unsigned char *)buffer, ic->ctext);
 	} else {
