@@ -41,7 +41,13 @@ int main(int argc, char *argv[])
 				if (currentarg + 1 < argc) {
 					strncpy_nt(p.cfgfile, argv[currentarg + 1], 512);
 					if (debug)
-						printf("Used config file: %s\n", p.cfgfile);
+						printf("Loading config file: %s\n", p.cfgfile);
+					if (!loadcfg(p.cfgfile, CT_CLI)) {
+						return 1;
+					}
+					if (!ibwloadcfg(p.cfgfile)) {
+						return 1;
+					}
 					currentarg++;
 				} else {
 					printf("Error: File for --config missing.\n");
@@ -51,17 +57,19 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	/* load config if available */
-	if (!loadcfg(p.cfgfile, CT_CLI)) {
-		return 1;
-	}
-	if (!ibwloadcfg(p.cfgfile)) {
-		return 1;
+	/* find configuration file if none was defined from command line */
+	if (p.cfgfile[0] == '\0') {
+		if (!loadcfg(p.cfgfile, CT_CLI)) {
+			return 1;
+		}
+		if (!ibwloadcfg(p.cfgfile)) {
+			return 1;
+		}
 	}
 
 	configlocale();
-	strncpy_nt(p.interface, "default", 32);
-	strncpy_nt(p.definterface, cfg.iface, 32);
+	strncpy_nt(p.interface, "default", MAXIFPARAMLEN);
+	strncpy_nt(p.definterface, cfg.iface, MAXIFPARAMLEN);
 	strncpy_nt(p.alias, "none", 32);
 
 	parseargs(&p, argc, argv);
@@ -85,7 +93,7 @@ int main(int argc, char *argv[])
 				printf("%" PRIu64 " interface(s) found\n", p.dbifcount);
 
 			if (p.dbifcount > 1) {
-				strncpy_nt(p.definterface, cfg.iface, 32);
+				strncpy_nt(p.definterface, cfg.iface, MAXIFPARAMLEN);
 			}
 		} else {
 			printf("Error: Unable to open database directory \"%s\": %s\n", cfg.dbdir, strerror(errno));
