@@ -48,6 +48,9 @@ void initparams(PARAMS *p)
 	p->alerttype = 0;
 	p->alertcondition = 0;
 	p->alertlimit = 0;
+
+	/* load default config */
+	defaultcfg();
 }
 
 void showhelp(PARAMS *p)
@@ -154,15 +157,22 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 			exit(EXIT_SUCCESS);
 		} else if ((strcmp(argv[currentarg], "-i") == 0) || (strcmp(argv[currentarg], "--iface") == 0) || (strcmp(argv[currentarg], "--interface") == 0)) {
 			if (currentarg + 1 < argc) {
-				if (strlen(argv[currentarg + 1]) > 31) {
-					printf("Error: Interface name is limited to 31 characters.\n");
-					exit(EXIT_FAILURE);
+				if (strchr(argv[currentarg + 1], '+') != NULL) {
+					if (strlen(argv[currentarg + 1]) > MAXIFPARAMLEN - 1) {
+						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						exit(EXIT_FAILURE);
+					}
+				} else {
+					if (strlen(argv[currentarg + 1]) > MAXIFLEN - 1) {
+						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						exit(EXIT_FAILURE);
+					}
 				}
-				strncpy_nt(p->interface, argv[currentarg + 1], 32);
+				strncpy_nt(p->interface, argv[currentarg + 1], MAXIFPARAMLEN);
 				if (strlen(p->interface)) {
 					p->defaultiface = 0;
 				} else {
-					strncpy_nt(p->definterface, p->interface, 32);
+					strncpy_nt(p->definterface, p->interface, MAXIFPARAMLEN);
 				}
 				if (debug)
 					printf("Used interface: \"%s\"\n", p->interface);
@@ -317,11 +327,12 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 			cfg.qmode = 8;
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				p->xmlmode = argv[currentarg + 1][0];
-				if (strlen(argv[currentarg + 1]) != 1 || strchr("afhdmyt", p->xmlmode) == NULL) {
+				if (strlen(argv[currentarg + 1]) != 1 || strchr("asfhdmyt", p->xmlmode) == NULL) {
 					if (!ishelprequest(argv[currentarg + 1]))
 						printf("Error: Invalid mode parameter \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid parameters for --xml:\n");
 					printf("    a - all (default)\n");
+					printf("    s - summary\n");
 					printf("    f - only 5 minutes\n");
 					printf("    h - only hours\n");
 					printf("    d - only days\n");
@@ -330,6 +341,9 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 					printf("    t - only top\n");
 					exit(EXIT_FAILURE);
 				}
+				if (p->xmlmode == 's') {
+					cfg.listjsonxml = 2;
+				}
 				currentarg++;
 			}
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
@@ -344,11 +358,12 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 			cfg.qmode = 10;
 			if (currentarg + 1 < argc && (strlen(argv[currentarg + 1]) == 1 || ishelprequest(argv[currentarg + 1]))) {
 				p->jsonmode = argv[currentarg + 1][0];
-				if (strlen(argv[currentarg + 1]) != 1 || strchr("afhdmyt", p->jsonmode) == NULL) {
+				if (strlen(argv[currentarg + 1]) != 1 || strchr("asfhdmyt", p->jsonmode) == NULL) {
 					if (!ishelprequest(argv[currentarg + 1]))
 						printf("Error: Invalid mode parameter \"%s\".\n", argv[currentarg + 1]);
 					printf(" Valid parameters for --json:\n");
 					printf("    a - all (default)\n");
+					printf("    s - summary\n");
 					printf("    f - only 5 minutes\n");
 					printf("    h - only hours\n");
 					printf("    d - only days\n");
@@ -357,6 +372,9 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 					printf("    t - only top\n");
 					exit(EXIT_FAILURE);
 				}
+				if (p->jsonmode == 's') {
+					cfg.listjsonxml = 2;
+				}
 				currentarg++;
 			}
 			if (currentarg + 1 < argc && isdigit(argv[currentarg + 1][0])) {
@@ -418,7 +436,11 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 			p->query = 0;
 		} else if (strcmp(argv[currentarg], "--rename") == 0) {
 			if (currentarg + 1 < argc) {
-				strncpy_nt(p->newifname, argv[currentarg + 1], 32);
+				if (strlen(argv[currentarg + 1]) > MAXIFLEN - 1) {
+					printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+					exit(EXIT_FAILURE);
+				}
+				strncpy_nt(p->newifname, argv[currentarg + 1], MAXIFLEN);
 				if (debug)
 					printf("Given new interface name: \"%s\"\n", p->newifname);
 				p->renameiface = 1;
@@ -516,15 +538,22 @@ void parseargs(PARAMS *p, const int argc, char **argv)
 				printf("Unknown parameter \"%s\". Use --help for help.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			} else {
-				if (strlen(argv[currentarg]) > 31) {
-					printf("Error: Interface name is limited to 31 characters.\n");
-					exit(EXIT_FAILURE);
+				if (strchr(argv[currentarg], '+') != NULL) {
+					if (strlen(argv[currentarg]) > MAXIFPARAMLEN - 1) {
+						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						exit(EXIT_FAILURE);
+					}
+				} else {
+					if (strlen(argv[currentarg]) > MAXIFLEN - 1) {
+						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						exit(EXIT_FAILURE);
+					}
 				}
-				strncpy_nt(p->interface, argv[currentarg], 32);
+				strncpy_nt(p->interface, argv[currentarg], MAXIFPARAMLEN);
 				if (strlen(p->interface)) {
 					p->defaultiface = 0;
 				} else {
-					strncpy_nt(p->definterface, p->interface, 32);
+					strncpy_nt(p->definterface, p->interface, MAXIFPARAMLEN);
 				}
 				if (debug)
 					printf("Used interface: \"%s\"\n", p->interface);
@@ -630,7 +659,7 @@ int parsealertargs(PARAMS *p, char **argv)
 
 	// condition
 	found = 0;
-	for (i = 0; i < 6; i++) {
+	for (i = 0; i < 3 + (cfg.estimatevisible * 3); i++) {
 		if (strcmp(argv[currentarg], alertconditions[i]) == 0) {
 			found = 1;
 			p->alertcondition = (unsigned int)i + 1;
@@ -736,7 +765,11 @@ void showalerthelp(void)
 	printf("    m, month, monthly      y, year, yearly\n\n");
 
 	printf(" <condition>\n");
-	printf("    rx, tx, total, rx_estimate, tx_estimate, total_estimate\n\n");
+	if (cfg.estimatevisible) {
+		printf("    rx, tx, total, rx_estimate, tx_estimate, total_estimate\n\n");
+	} else {
+		printf("    rx, tx, total\n\n");
+	}
 
 	printf(" <limit>\n");
 	printf("    greater than zero integer without decimals\n\n");
@@ -754,7 +787,7 @@ void showstylehelp(void)
 	printf("    2 - average traffic rate in summary output\n");
 	printf("    3 - average traffic rate in all outputs if available\n");
 	printf("    4 - disable terminal control characters in -l / --live\n");
-	printf("        and show raw values in --oneline\n");
+	printf("        and -tr / --traffic, show raw values in --oneline\n");
 }
 
 void handleshowalert(PARAMS *p)
@@ -988,8 +1021,8 @@ void handleshowdata(PARAMS *p)
 	} else if ((cfg.qmode == 0 || cfg.qmode == 8 || cfg.qmode == 10) && (p->dbifcount > 1)) {
 
 		if (cfg.qmode == 0) {
-			if (cfg.ostyle != 0) {
-				printf("\n                      rx      /      tx      /     total    /   estimated\n");
+			if (cfg.ostyle != 0 && cfg.estimatevisible) {
+				printf("\n                      rx      /      tx      /     total    /   %s\n", cfg.estimatetext);
 			} else {
 				printf("\n                      rx      /      tx      /     total\n");
 			}
@@ -1006,7 +1039,7 @@ void handleshowdata(PARAMS *p)
 		dbifl_i = dbifl;
 
 		while (dbifl_i != NULL) {
-			strncpy_nt(p->interface, dbifl_i->interface, 32);
+			strncpy_nt(p->interface, dbifl_i->interface, MAXIFLEN);
 			if (debug)
 				printf("\nProcessing interface \"%s\"...\n", p->interface);
 			if (cfg.qmode == 0) {
@@ -1039,9 +1072,13 @@ void showoneinterface(PARAMS *p)
 
 	if (cfg.qmode == 5) {
 		if (cfg.ostyle != 0) {
-			printf("\n                      rx      /      tx      /     total    /   estimated\n");
+			printf("\n                      rx      /      tx      /     total");
+			if (cfg.estimatevisible) {
+				printf("    /   %s", cfg.estimatetext);
+			}
+			printf("\n");
 		} else {
-			printf("\n                      rx      /      tx      /     total\n");
+			printf("\n                 rx      /      tx      /     total\n");
 		}
 	}
 	if (cfg.qmode != 8 && cfg.qmode != 10) {
@@ -1119,7 +1156,7 @@ void handleifselection(PARAMS *p)
 	}
 
 	if (strlen(p->definterface)) {
-		strncpy_nt(p->interface, p->definterface, 32);
+		strncpy_nt(p->interface, p->definterface, MAXIFPARAMLEN);
 		return;
 	}
 
@@ -1146,7 +1183,7 @@ void handleifselection(PARAMS *p)
 			dbifl_iterator = dbifl;
 			while (dbifl_iterator != NULL) {
 				if (iflistsearch(&ifl, dbifl_iterator->interface)) {
-					strncpy_nt(p->interface, dbifl_iterator->interface, 32);
+					strncpy_nt(p->interface, dbifl_iterator->interface, MAXIFLEN);
 					iffound = 1;
 					if (debug)
 						printf("Automatically selected interface with db: \"%s\"\n", p->interface);
@@ -1158,7 +1195,7 @@ void handleifselection(PARAMS *p)
 
 		if (!iffound) {
 			if (ifcount > 0) {
-				strncpy_nt(p->interface, ifl->interface, 32);
+				strncpy_nt(p->interface, ifl->interface, MAXIFLEN);
 				if (debug)
 					printf("Automatically selected interface without db: \"%s\"\n", p->interface);
 			} else {
@@ -1176,7 +1213,7 @@ void handleifselection(PARAMS *p)
 			iflistfree(&dbifl);
 			exit(EXIT_FAILURE);
 		}
-		strncpy_nt(p->interface, dbifl->interface, 32);
+		strncpy_nt(p->interface, dbifl->interface, MAXIFLEN);
 		if (debug)
 			printf("Automatically selected interface from db: \"%s\"\n", p->interface);
 	}
