@@ -42,7 +42,10 @@ int main(int argc, char *argv[])
 				if (currentarg + 1 < argc) {
 					strncpy_nt(p.cfgfile, argv[currentarg + 1], 512);
 					if (debug)
-						printf("Used config file: %s\n", p.cfgfile);
+						printf("Loading config file: %s\n", p.cfgfile);
+					if (!loadcfg(p.cfgfile, CT_Image)) {
+						return 1;
+					}
 					currentarg++;
 				} else {
 					printf("Error: File for --config missing.\n");
@@ -52,14 +55,16 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	/* load config if available */
-	if (!loadcfg(p.cfgfile, CT_Image)) {
-		return 1;
+	/* find configuration file if none was defined from command line */
+	if (p.cfgfile[0] == '\0') {
+		if (!loadcfg(p.cfgfile, CT_Image)) {
+			return 1;
+		}
 	}
 	cfg.qmode = 0;
 
 	configlocale();
-	strncpy_nt(p.interface, cfg.iface, 32);
+	strncpy_nt(p.interface, cfg.iface, MAXIFPARAMLEN);
 	ic.current = time(NULL);
 
 	parseargs(&p, &ic, argc, argv);
@@ -102,6 +107,9 @@ void initiparams(IPARAMS *p)
 	p->cache = 0;
 	p->help = 0;
 	p->limit = -1;
+
+	/* load default config */
+	defaultcfg();
 }
 
 void showihelp(IPARAMS *p)
@@ -173,11 +181,18 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 			p->help = 1;
 		} else if ((strcmp(argv[currentarg], "-i") == 0) || (strcmp(argv[currentarg], "--iface")) == 0 || (strcmp(argv[currentarg], "--interface") == 0)) {
 			if (currentarg + 1 < argc) {
-				if (strlen(argv[currentarg + 1]) > 31) {
-					printf("Error: Interface name is limited to 31 characters.\n");
-					exit(EXIT_FAILURE);
+				if (strchr(argv[currentarg + 1], '+') != NULL) {
+					if (strlen(argv[currentarg + 1]) > MAXIFPARAMLEN - 1) {
+						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						exit(EXIT_FAILURE);
+					}
+				} else {
+					if (strlen(argv[currentarg + 1]) > MAXIFLEN - 1) {
+						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						exit(EXIT_FAILURE);
+					}
 				}
-				strncpy_nt(p->interface, argv[currentarg + 1], 32);
+				strncpy_nt(p->interface, argv[currentarg + 1], MAXIFPARAMLEN);
 				if (debug)
 					printf("Used interface: \"%s\"\n", p->interface);
 				currentarg++;
@@ -379,7 +394,7 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 				if (cfg.fivegresultcount < FIVEGMINRESULTCOUNT) {
 					printf("Error: Invalid limit parameter \"%s\" for %s. A value equal or over %d is expected.\n", argv[currentarg + 1], argv[currentarg], FIVEGMINRESULTCOUNT);
 					exit(EXIT_FAILURE);
-				} else if (cfg.fivegresultcount > cfg.fiveminutehours * 12) {
+				} else if (cfg.fivegresultcount > cfg.fiveminutehours * 12 && cfg.fiveminutehours > 0) {
 					printf("Error: Invalid limit parameter \"%s\" for %s. Value cannot be larger than configured data retention (5MinuteHours %d * 12 = %d).\n", argv[currentarg + 1], argv[currentarg], cfg.fiveminutehours, cfg.fiveminutehours * 12);
 					exit(EXIT_FAILURE);
 				}
@@ -494,11 +509,18 @@ void parseargs(IPARAMS *p, IMAGECONTENT *ic, int argc, char **argv)
 				printf("Unknown parameter \"%s\". Use --help for help.\n", argv[currentarg]);
 				exit(EXIT_FAILURE);
 			} else {
-				if (strlen(argv[currentarg]) > 31) {
-					printf("Error: Interface name is limited to 31 characters.\n");
-					exit(EXIT_FAILURE);
+				if (strchr(argv[currentarg], '+') != NULL) {
+					if (strlen(argv[currentarg]) > MAXIFPARAMLEN - 1) {
+						printf("Error: Interface merge is limited to %d characters.\n", MAXIFPARAMLEN - 1);
+						exit(EXIT_FAILURE);
+					}
+				} else {
+					if (strlen(argv[currentarg]) > MAXIFLEN - 1) {
+						printf("Error: Interface name is limited to %d characters.\n", MAXIFLEN - 1);
+						exit(EXIT_FAILURE);
+					}
 				}
-				strncpy_nt(p->interface, argv[currentarg], 32);
+				strncpy_nt(p->interface, argv[currentarg], MAXIFPARAMLEN);
 				if (debug)
 					printf("Used interface: \"%s\"\n", p->interface);
 			}
@@ -592,7 +614,7 @@ void handledatabase(IPARAMS *p, IMAGECONTENT *ic)
 			printf("Error: Unable to discover suitable interface from database.\n");
 			exit(EXIT_FAILURE);
 		}
-		strncpy_nt(p->interface, dbifl->interface, 32);
+		strncpy_nt(p->interface, dbifl->interface, MAXIFLEN);
 		iflistfree(&dbifl);
 		if (debug)
 			printf("Automatically selected interface: \"%s\"\n", p->interface);
