@@ -1837,6 +1837,80 @@ START_TEST(db_getdata_range_with_merged_interfaces)
 }
 END_TEST
 
+START_TEST(db_getdata_range_with_long_merged_interfaces)
+{
+	int ret, i;
+	char timestamp[64];
+	dbdatalist *datalist = NULL, *datalist_i = NULL;
+	dbdatalistinfo datainfo;
+
+	cfg.monthrotate = 1;
+
+	ret = db_open_rw(1);
+	ck_assert_int_eq(ret, 1);
+	ret = db_addinterface("ethtester");
+	ck_assert_int_eq(ret, 1);
+	ret = db_addinterface("ethotherthing");
+	ck_assert_int_eq(ret, 1);
+	ret = db_addinterface("ethreallyfast");
+	ck_assert_int_eq(ret, 1);
+	ret = db_addinterface("ethturtle");
+	ck_assert_int_eq(ret, 1);
+
+	for (i = 1; i <= 20; i++) {
+		ret = db_addtraffic_dated("ethtester", 1, 2, get_timestamp(2010, 9, i, 0, 0));
+		ck_assert_int_eq(ret, 1);
+		ret = db_addtraffic_dated("ethotherthing", 3, 7, get_timestamp(2010, 9, i, 0, 0));
+		ck_assert_int_eq(ret, 1);
+		ret = db_addtraffic_dated("ethreallyfast", 4, 8, get_timestamp(2010, 9, i, 0, 0));
+		ck_assert_int_eq(ret, 1);
+		ret = db_addtraffic_dated("ethturtle", 5, 9, get_timestamp(2010, 9, i, 0, 0));
+		ck_assert_int_eq(ret, 1);
+	}
+
+	ret = db_getdata_range(&datalist, &datainfo, "ethtester+ethotherthing+ethreallyfast+ethturtle", "month", 0, "", "");
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(datainfo.count, 1);
+	datalist_i = datalist;
+	i = 0;
+	while (datalist_i != NULL) {
+		switch (i) {
+			case 0:
+				strftime(timestamp, 64, "%Y-%m-%d", localtime(&datalist_i->timestamp));
+				ck_assert_str_eq(timestamp, "2010-09-01");
+				ck_assert_int_eq(datalist_i->rx, 260);
+				ck_assert_int_eq(datalist_i->tx, 520);
+				break;
+		}
+		datalist_i = datalist_i->next;
+		i++;
+	}
+	dbdatalistfree(&datalist);
+
+	ret = db_getdata_range(&datalist, &datainfo, "ethotherthing+ethreallyfast+ethturtle", "month", 0, "", "");
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(datainfo.count, 1);
+	datalist_i = datalist;
+	i = 0;
+	while (datalist_i != NULL) {
+		switch (i) {
+			case 0:
+				strftime(timestamp, 64, "%Y-%m-%d", localtime(&datalist_i->timestamp));
+				ck_assert_str_eq(timestamp, "2010-09-01");
+				ck_assert_int_eq(datalist_i->rx, 240);
+				ck_assert_int_eq(datalist_i->tx, 480);
+				break;
+		}
+		datalist_i = datalist_i->next;
+		i++;
+	}
+	dbdatalistfree(&datalist);
+
+	ret = db_close();
+	ck_assert_int_eq(ret, 1);
+}
+END_TEST
+
 START_TEST(db_addtraffic_without_monthrotate)
 {
 	int ret, i;
@@ -2193,6 +2267,17 @@ START_TEST(getifaceinquery_can_create_merge_queries)
 }
 END_TEST
 
+START_TEST(getifaceinquery_can_create_merge_query_longer_than_single_interface_maxlen)
+{
+	char *result;
+
+	result = getifaceinquery("eth0+em1+eth1+eth2+em2+eth3+eth4+em3+eth5");
+	ck_assert_ptr_ne(result, NULL);
+	ck_assert_str_eq(result, "\"eth0\",\"em1\",\"eth1\",\"eth2\",\"em2\",\"eth3\",\"eth4\",\"em3\",\"eth5\"");
+	free(result);
+}
+END_TEST
+
 START_TEST(getifaceinquery_does_not_tolerate_nonsense)
 {
 	char *result;
@@ -2362,6 +2447,7 @@ START_TEST(db_getinterfaceinfo_can_handle_interface_merges)
 	ck_assert_int_eq(info.txtotal, 1);
 	ck_assert_int_gt(info.updated, 1000);
 	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0+ethnone");
 
 	ret = db_getinterfaceinfo("eth0+eth1", &info);
 	ck_assert_int_eq(ret, 1);
@@ -2369,6 +2455,7 @@ START_TEST(db_getinterfaceinfo_can_handle_interface_merges)
 	ck_assert_int_eq(info.txtotal, 3);
 	ck_assert_int_gt(info.updated, 1000);
 	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0+eth1");
 
 	ret = db_getinterfaceinfo("eth1+eth2", &info);
 	ck_assert_int_eq(ret, 1);
@@ -2376,6 +2463,7 @@ START_TEST(db_getinterfaceinfo_can_handle_interface_merges)
 	ck_assert_int_eq(info.txtotal, 7);
 	ck_assert_int_gt(info.updated, 1000);
 	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth1+eth2");
 
 	ret = db_getinterfaceinfo("eth0+eth1+eth2", &info);
 	ck_assert_int_eq(ret, 1);
@@ -2383,6 +2471,62 @@ START_TEST(db_getinterfaceinfo_can_handle_interface_merges)
 	ck_assert_int_eq(info.txtotal, 8);
 	ck_assert_int_gt(info.updated, 1000);
 	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0+eth1+eth2");
+
+	ret = db_close();
+	ck_assert_int_eq(ret, 1);
+}
+END_TEST
+
+START_TEST(db_getinterfaceinfo_can_handle_interface_merges_with_long_name)
+{
+	int ret;
+	interfaceinfo info;
+
+
+	ret = db_open_rw(1);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addtraffic("eth0notsolong", 1, 1);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addtraffic("eth1withratherlongname", 2, 2);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_addtraffic("eth2withstillmuchlongername", 5, 5);
+	ck_assert_int_eq(ret, 1);
+
+	ret = db_getinterfaceinfo("eth0notsolong+ethnone", &info);
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(info.rxtotal, 1);
+	ck_assert_int_eq(info.txtotal, 1);
+	ck_assert_int_gt(info.updated, 1000);
+	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0notsolong+ethnone");
+
+	ret = db_getinterfaceinfo("eth0notsolong+eth1withratherlongname", &info);
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(info.rxtotal, 3);
+	ck_assert_int_eq(info.txtotal, 3);
+	ck_assert_int_gt(info.updated, 1000);
+	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0notsolong+eth1withratherlongname");
+
+	ret = db_getinterfaceinfo("eth1withratherlongname+eth2withstillmuchlongername", &info);
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(info.rxtotal, 7);
+	ck_assert_int_eq(info.txtotal, 7);
+	ck_assert_int_gt(info.updated, 1000);
+	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth1withratherlongname+eth2withstillmuchlongername");
+
+	ret = db_getinterfaceinfo("eth0notsolong+eth1withratherlongname+eth2withstillmuchlongername", &info);
+	ck_assert_int_eq(ret, 1);
+	ck_assert_int_eq(info.rxtotal, 8);
+	ck_assert_int_eq(info.txtotal, 8);
+	ck_assert_int_gt(info.updated, 1000);
+	ck_assert_int_lt(info.updated, 2100000000);
+	ck_assert_str_eq(info.name, "eth0notsolong+eth1withratherlongname+eth2withstillmuchlongername");
 
 	ret = db_close();
 	ck_assert_int_eq(ret, 1);
@@ -2823,6 +2967,7 @@ void add_dbsql_tests(Suite *s)
 	tcase_add_test(tc_dbsql, db_getdata_range_can_get_hours_with_range_limiting_end_with_limit);
 	tcase_add_test(tc_dbsql, db_getdata_range_can_get_hours_with_range_on_same_hour);
 	tcase_add_test(tc_dbsql, db_getdata_range_with_merged_interfaces);
+	tcase_add_test(tc_dbsql, db_getdata_range_with_long_merged_interfaces);
 	tcase_add_test(tc_dbsql, db_addtraffic_without_monthrotate);
 	tcase_add_test(tc_dbsql, db_addtraffic_with_monthrotate);
 	tcase_add_test(tc_dbsql, db_addtraffic_without_monthrotate_utc);
@@ -2833,11 +2978,13 @@ void add_dbsql_tests(Suite *s)
 	tcase_add_test(tc_dbsql, db_get_date_generator_can_generate_dates_with_monthrotate_utc);
 	tcase_add_test(tc_dbsql, getifaceinquery_does_not_mess_regular_interfaces);
 	tcase_add_test(tc_dbsql, getifaceinquery_can_create_merge_queries);
+	tcase_add_test(tc_dbsql, getifaceinquery_can_create_merge_query_longer_than_single_interface_maxlen);
 	tcase_add_test(tc_dbsql, getifaceinquery_does_not_tolerate_nonsense);
 	tcase_add_test(tc_dbsql, db_getinterfaceid_can_get_ids);
 	tcase_add_test(tc_dbsql, db_getinterfaceidin_can_get_in_groups);
 	tcase_add_test(tc_dbsql, db_getinterfaceidin_can_handle_error_situations);
 	tcase_add_test(tc_dbsql, db_getinterfaceinfo_can_handle_interface_merges);
+	tcase_add_test(tc_dbsql, db_getinterfaceinfo_can_handle_interface_merges_with_long_name);
 	tcase_add_test(tc_dbsql, db_getinterfaceinfo_can_handle_invalid_input);
 	tcase_add_test(tc_dbsql, getqueryinterfacecount_can_count);
 	tcase_add_test(tc_dbsql, top_list_returns_items_in_correct_order);
